<div align="center">
  <img width="200" height="200"
    src="https://s3.amazonaws.com/pix.iemoji.com/images/emoji/apple/ios-11/256/crayon.png">
  <h1>@jimp/gif</h1>
  <p>Default Jimp gif decoder.</p>
</div>

NOTE: Encoder currently unavailable.
